#ifndef _MY_BUTTON_H
#define _MY_BUTTON_H

//////////////////////
// test-app/MyButton.H
//////////////////////
//
// OpDesk (Version 0.70)
// This file is part of the OpDesk node graph FLTK widget.
// Copyright (C) 2009 by Greg Ercolano.
//
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Library General Public
// License as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Library General Public License for more details.
//
// You should have received a copy of the GNU Library General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA.
//

#include "everything.H"

// APP'S INCLUDE FILES
#include "MyButton.H"
#include "MyConstantDialog.H"

// CUSTOM FL_OPBUTTON
//    Our app derives from the Fl_OpButton widget to augment it with our app-specific code.
//
class MyButton : public Fl_OpButton {
public:
    enum DataType { INT='i', FLOAT='f', STRING='s' };
private:
    std::string const_val;
    DataType dtype;
    MyConstantDialog *const_dialog;

    // Virtual: Called by Fl_OpDesk when a connection is being made.
    int Connecting(Fl_OpButton *but, std::string &errmsg);

    // Virtual: Called by Fl_OpDesk when a connection is being dropped.
    void Disconnecting(Fl_OpButton *but) {
	printf("**DISCONNECTING*** '%s' <-> '%s'\n",
	    this->GetFullName().c_str(),
	     but->GetFullName().c_str());
    }

    void MyButtonCallback2();
    static void MyButtonCallback(Fl_Widget *w, void *userdata);

public:
    // CTORS
    MyButton(const char *buttname, Fl_OpButtonType io, DataType dtype);
    MyButton(const MyButton &o);

    // DATA TYPES/CONSTANTS
    void               SetConstantValue(const char *val);
    const std::string& GetConstantValue() const;
    DataType           GetDataType() const;
    void               SetDataType(DataType dt);
    const char*        GetDataTypeStr() const;
    int                SetDataTypeStr(const char *s);
    std::string        GetVarValue() const;

    // LAYOUT LOAD/SAVE
    int SaveLayout(FILE *fp);
    int LoadLayout(FILE *fp, int &line, std::string &errmsg);

    // MISC
    void DoButtonMenu();

    // FLTK
    int handle(int e);
    void draw();

};

#endif
